pub struct AnnotationOptions { /* private fields */ }Expand description
Options for applying annotations.
Implementations
Sourceimpl AnnotationOptions
impl AnnotationOptions
Sourcepub fn with_product(self, product: Option<impl Into<String>>) -> Self
pub fn with_product(self, product: Option<impl Into<String>>) -> Self
Overrides the product string in the profile. None uses the default,
which is PID <pid>.
The Firefox Profiler prominently displays the product and OS-CPU string
together in the form <product> - <OS-CPU>.
Sourcepub fn with_os_cpu(self, os_cpu: Option<impl Into<String>>) -> Self
pub fn with_os_cpu(self, os_cpu: Option<impl Into<String>>) -> Self
Overrides the OS and CPU string in the profile. None uses the
default, which looks like Ubuntu 24.0.04.4 LTS.
The Firefox Profiler prominently displays the product and OS-CPU string
together in the form <product> - <OS-CPU>.