Capture

Struct Capture 

pub struct Capture { /* private fields */ }
An in-progress capture of profile annotations.

To start a capture, use CaptureOptions::start, CaptureOptions::blocking_start, or CaptureOptions::try_start.

Only one Capture may exist at one time.

Implementations

Source

impl Capture

pub fn finish(self) -> Annotations

Finishes recording profile annotations and returns what was recorded.

pub fn abort(self)

Aborts recording profile annotations.

This is equivalent to dropping the Capture object.

pub fn is_active() -> bool

Returns true if a profile annotation capture is ongoing.

This only reports the status of annotation captures. It does not indicate whether samply or perf or another profiler is currently capturing profile data for this process (this crate does not provide a way to do that).