CaptureOptions

Struct CaptureOptions 

pub struct CaptureOptions { /* private fields */ }
Options for capturing profile annotations.

Implementations

Source

impl CaptureOptions

pub fn new() -> Self

Creates new capture parameters with default settings.

pub fn with_memory_limit(self, memory_limit: Option<usize>) -> Self

Sets a limit on the amount of memory that can be used for recording captured spans to memory_limit, in bytes. If memory_limit is None, then there will be no limit (which is also the default).

The limit is honored approximately. Recording a span takes Span::BYTES bytes.

pub fn with_record_rss(self, record_rss: bool) -> Self

Enables or disables recording the amount of memory in use (the resident set size) during the capture. By default, RSS is recorded every 100 milliseconds. When this feature is enabled, capture runs a thread for recording the data.

pub async fn start(self) -> Capture

Starts capturing profile annotations, returning a Capture that can be used to finish or abort captures. Dropping the Capture will also abort capturing.

For use in asynchronous contexts. If a capture is already in progress, this function will wait for it to complete before starting a new one.

pub fn blocking_start(self) -> Capture

Starts capturing profile annotations, returning a Capture that can be used to finish or abort captures. Dropping the Capture will also abort capturing.

For use in blocking contexts. If a capture is already in progress, this function will wait for it to complete before starting a new one.

Panic

Panics if called from an asynchronous execution context.

pub fn try_start(self) -> Result<Capture, Self>

Starts capturing profile annotations, returning a Capture that can be used to finish or abort captures. Dropping the Capture will also abort capturing.

If a capture is already in progress, this function returns an error instead of waiting.