Event

Struct Event 

pub struct Event(/* private fields */);
Annotates an event during a Capture.

When a Capture is running, use this type to record an event along with a name, category, and tooltip.

An event happens at a point in time; use Span to record a timespan.

When Capture is not active, Event has minimal overhead.

Implementations

Source

impl Event

pub fn new(name: &'static str) -> Self

Constructs a new Event with the given name.

Event does nothing when markers are not being captured.

The name should ordinarily be a short static string indicating what the event did. The Firefox Profiler’s marker chart view shows all the events in a thread with the same name and category on a single horizontal timeline (unless that would cause overlaps).

pub fn with_category(self, category: &'static str) -> Self

Adds category to this event.

The Firefox Profiler’s marker chart view groups the markers in each category and labels them with the category name.

The default category is “Other”.

pub fn with_tooltip<F>(self, tooltip: F) -> Self
where F: FnOnce() -> String,

Evaluates tooltip and adds it to this event.

The Firefox Profiler shows the given tooltip in the marker chart timeline (often truncated) and on hover, and as “details” in the marker table view.

tooltip is only evaluated if capturing is active.

pub fn record(self)

Records the event.